#############
Basic Drawing
#############

Let's start by looking at a very simple ``PySketcher`` sketch which draws a single line:

.. literalinclude:: examples/basic_drawing_1.py
    :end-before: # End Here
    :language: python

This draws the image shown here:

.. figure:: /tutorial/examples/images/basic_drawing_1.png
